package com.ruoyi.web.controller.buyerapi;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import cn.hutool.core.util.IdUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.buyerapi.domain.BuyerGoods;
import com.ruoyi.buyerapi.service.IBuyerGoodsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 商品管理Controller
 * 
 * @author ruoyi
 * @date 2022-09-19
 */
@Api(tags = "商品管理")
@RestController
@RequestMapping("/buyer/goods")
public class BuyerGoodsController extends BaseController
{
    @Autowired
    private IBuyerGoodsService buyerGoodsService;

    /**
     * 查询商品管理列表
     */
    @ApiOperation(value = "查询商品管理列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "name", value = "商品名称", required = true, paramType = "query")
    })
    @PreAuthorize("@ss.hasPermi('system:goods:list')")
    @GetMapping("/list")
    public TableDataInfo list(BuyerGoods buyerGoods)
    {
        startPage();
        List<BuyerGoods> list = buyerGoodsService.selectBuyerGoodsList(buyerGoods);
        return getDataTable(list);
    }

    /**
     * 导出商品管理列表
     */
    @ApiOperation(value = "导出商品管理列表")
    @PreAuthorize("@ss.hasPermi('system:goods:export')")
    @Log(title = "商品管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BuyerGoods buyerGoods)
    {
        List<BuyerGoods> list = buyerGoodsService.selectBuyerGoodsList(buyerGoods);
        ExcelUtil<BuyerGoods> util = new ExcelUtil<BuyerGoods>(BuyerGoods.class);
        util.exportExcel(response, list, "商品管理数据");
    }

    /**
     * 获取商品管理详细信息
     */
    @ApiOperation(value = "获取商品管理详细信息")
    @PreAuthorize("@ss.hasPermi('system:goods:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return AjaxResult.success(buyerGoodsService.selectBuyerGoodsById(id));
    }

    /**
     * 新增商品管理
     */
    @ApiOperation(value = "新增商品管理")
    @PreAuthorize("@ss.hasPermi('system:goods:add')")
    @Log(title = "商品管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BuyerGoods buyerGoods)
    {
        buyerGoods.setId(IdUtil.simpleUUID());
        buyerGoods.setCreateBy(getUsername());
        return toAjax(buyerGoodsService.insertBuyerGoods(buyerGoods));
    }

    /**
     * 修改商品管理
     */
    @ApiOperation(value = "修改商品管理")
    @PreAuthorize("@ss.hasPermi('system:goods:edit')")
    @Log(title = "商品管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BuyerGoods buyerGoods)
    {
        buyerGoods.setUpdateBy(getUsername());
        return toAjax(buyerGoodsService.updateBuyerGoods(buyerGoods));
    }

    /**
     * 删除商品管理
     */
    @ApiOperation(value = "删除商品管理")
    @PreAuthorize("@ss.hasPermi('system:goods:remove')")
    @Log(title = "商品管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(buyerGoodsService.deleteBuyerGoodsByIds(ids));
    }
}
